@@ -107,10 +107,12 @@ void Config::read()
     data.general.metaDataOutputDirectory = conf->readEntry( "metaDataOutputDirectory", QDir::homeDirPath() + "/soundKonverter/%b/%d - %n - %a - %t" );
     data.general.copyStructureOutputDirectory = conf->readEntry( "copyStructureOutputDirectory", QDir::homeDirPath() + "/soundKonverter" );
     data.general.useVFATNames = conf->readBoolEntry( "useVFATNames", true );
+    data.general.conflictHandling = conf->readNumEntry( "conflictHandling", 0 );
     data.general.priority = conf->readNumEntry( "priority", 10 );
     data.general.numFiles = conf->readNumEntry( "numFiles", 3 );
     data.general.updateDelay = conf->readNumEntry( "updateDelay", 500 );
     data.general.askForNewOptions = conf->readBoolEntry( "askForNewOptions", true );
+    data.general.executeUserScript = conf->readBoolEntry( "executeUserScript", false );
     data.general.showToolBar = conf->readBoolEntry( "showToolBar", false );
 
     conf->setGroup( "Plugins" );
@@ -132,7 +134,7 @@ void Config::read()
     ripper = conf->readEntry( "ripper", "kio_audiocd" );
 
     if( ripper == "kio_audiocd" ) rank = 10000;
-    else rank = 60;
+    else rank = 60; // kio_audiocd ranking
     currentRipper = 0; // this is a valid ripper (kio_audiocd)
     for( QValueList<RipperPlugin*>::Iterator b = rippers.begin(); b != rippers.end(); ++b ) {
         binaries[ (*b)->rip.bin ] = "";
@@ -141,7 +143,7 @@ void Config::read()
             currentRipper = (*b);
         }
         if( (*b)->rip.bin == ripper ) {
-            rank = 10000; // should be high enougth to overbid the other plugins
+            rank = 10000; // should be high enough to overbid the other plugins
             currentRipper = (*b);
         }
     }
@@ -290,10 +292,12 @@ void Config::write( bool sync )
     conf->writeEntry( "metaDataOutputDirectory", data.general.metaDataOutputDirectory );
     conf->writeEntry( "copyStructureOutputDirectory", data.general.copyStructureOutputDirectory );
     conf->writeEntry( "useVFATNames", data.general.useVFATNames );
+    conf->writeEntry( "conflictHandling", data.general.conflictHandling );
     conf->writeEntry( "priority", data.general.priority );
     conf->writeEntry( "numFiles", data.general.numFiles );
     conf->writeEntry( "updateDelay", data.general.updateDelay );
     conf->writeEntry( "askForNewOptions", data.general.askForNewOptions );
+    conf->writeEntry( "executeUserScript", data.general.executeUserScript );
     conf->writeEntry( "showToolBar", data.general.showToolBar );
 
     conf->setGroup( "Plugins" );
@@ -882,6 +886,15 @@ void Config::loadPlugins()
                                     logger->log( 1000, "    adding extension: `" + *c + "'" );
                                 }
                                 (*c).extensions += extensions;
+                                // add extensions (from format file) HACK
+                                extensions = formatInfo->extensions;
+                                if( !extensions.isEmpty() ) {
+                                    logger->log( 1000, "   found extensions..." );
+                                    for( QStringList::Iterator c = extensions.begin(); c != extensions.end(); ++c ) {
+                                        logger->log( 1000, "    adding extension: `" + *c + "'" );
+                                    }
+                                    (*c).extensions += extensions;
+                                }
                                 // add extensions for correction file mime types
                                 for( QStringList::Iterator d = (*c).correction_file_mime_types.begin(); d != (*c).correction_file_mime_types.end(); ++d ) {
                                     logger->log( 1000, "   found correction mime type: `" + *d + "'" );
@@ -1040,11 +1053,12 @@ QStringList Config::allFormats()
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1067,11 +1081,12 @@ QStringList Config::allEncodableFormats()
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).mime_types.first() != "application/octet-stream" ) {
             if( !(*it).encoder->enc.lossy.enabled && !(*it).encoder->enc.lossless.enabled && !(*it).encoder->enc.hybrid.enabled ) continue;
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1087,20 +1102,21 @@ QStringList Config::allLossyEncodableFormats()
     QStringList list;
 
     //kdDebug() << "entering: `" << "Config::allLossyEncodableFormats()" << "'" << endl;
-    logger->log( 1000, "entering: `Config::allLossyEncodableFormats()'" );
+//     logger->log( 1000, "entering: `Config::allLossyEncodableFormats()'" );
 
     for( QValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it ) {
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
-        logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
+//         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).encoder->enc.lossy.enabled && (*it).compressionType & FormatInfo::lossy && (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
-            logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+//             logger->log( 1000, "  extension: `" + extension + "'" );
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
-                logger->log( 1000, "   (added)" );
+//                 logger->log( 1000, "   (added)" );
             }
         }
     }
@@ -1119,11 +1135,12 @@ QStringList Config::allLosslessEncodableFormats()
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).encoder->enc.lossless.enabled && (*it).compressionType & FormatInfo::lossless && (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1145,11 +1162,12 @@ QStringList Config::allHybridEncodableFormats()
         //kdDebug() << " mime type: `" << (*it).mime_types.first() << "'" << endl;
         logger->log( 1000, " mime type: `" + (*it).mime_types.first() + "'" );
         if( (*it).encoder != 0 && binaries[(*it).encoder->enc.bin] != "" && (*it).encoder->enc.hybrid.enabled && (*it).compressionType & FormatInfo::hybrid && (*it).mime_types.first() != "application/octet-stream" ) {
-            QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first();
-            extension.remove( 0, 2 );
+//             QString extension = KMimeType::mimeType( (*it).mime_types.first() )->patterns().first().lower();
+//             extension.remove( 0, 2 );
+            QString extension = (*it).extensions.first().lower();
             //kdDebug() << "  extension: `" << extension << "'" << endl;
             logger->log( 1000, "  extension: `" + extension + "'" );
-            if( !extension.isEmpty() ) {
+            if( !extension.isEmpty() && !list.contains(extension) ) {
                 list.append( extension );
                 //kdDebug() << "   (added)" << endl;
                 logger->log( 1000, "   (added)" );
@@ -1400,11 +1418,17 @@ QString Config::fileFilter( bool wav )
             //temp.stripWhiteSpace(); // NOTE doesn't work
             if( temp != "" && temp.length() < 80 ) {
                 temp.remove( 0, 1 );
-                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files") + " (" + temp + ")";
+                temp = "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files") + " (" + temp + ")";
+                if( !filter2.contains(temp) ) { // HACK when unsing multiple mime types, there were too much entries
+                    filter2 += temp;
+                }
             }
             else if( temp != "" ) {
                 temp.remove( 0, 1 );
-                filter2 += "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files");
+                temp = "\n" + temp + "|" + (*a).extensions.first() + " " + i18n("files");
+                if( !filter2.contains(temp) ) { // HACK when unsing multiple mime types, there were too much entries
+                    filter2 += temp;
+                }
             }
         }
     }
@@ -1427,7 +1451,10 @@ QStringList Config::fileTypes( bool wav )
             for( QStringList::Iterator b = (*a).extensions.begin(); b != (*a).extensions.end(); ++b ) {
                 if( !temp.contains(*b,false) ) temp.append( (*b).lower() + ", " );
             }
-            if( temp != "" ) types.append( temp.left( temp.length()-2 ) );
+            if( temp != "" ) {
+                temp = temp.left( temp.length() - 2 );
+                if( types.findIndex(temp) == -1 ) types.append( temp );
+            }
         }
     }
 
