@@ -15,10 +15,12 @@
 #include <math.h>
 
 #include <klocale.h>
+#include <kglobal.h>
 //#include <kdebug.h>
 #include <ktempfile.h>
 #include <kio/job.h>
 //#include <kprocess.h>
+#include <kstandarddirs.h>
 
 #include <qfile.h>
 #include <qtimer.h>
@@ -81,21 +83,32 @@ void Convert::get( ConvertItem* item )
     logger->log( item->logID, i18n("Getting file") );
     item->state = ConvertItem::get;
 
-    QString src = item->fileListItem->options.filePathName;
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Getting file")+"... 00 %" );
 
-//     KURL source( src );
-    KURL source;
-    source.setPath( src );
+    KURL source( item->fileListItem->options.filePathName );
     KURL destination( item->tempInFile->name() );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::getCorrection( ConvertItem* item )
@@ -111,20 +124,32 @@ void Convert::getCorrection( ConvertItem* item )
         return;
     }
 
-//     KURL source( file.name() );
-    KURL source;
-    source.setPath( file.name() );
+    KURL source( file.name() );
     KURL destination( item->correctionInFile );
 
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Getting correction file")+"... 00 %" );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::rip( ConvertItem* item )
@@ -264,7 +289,7 @@ void Convert::decode( ConvertItem* item )
     t_str.replace( "%p", param );
     param = config->binaries[plugin->dec.bin] + " " + t_str;
 
-    param.simplifyWhiteSpace();
+    param = param.simplifyWhiteSpace();
 
     params = QStringList::split( ' ', param );
 
@@ -395,7 +420,8 @@ void Convert::encode( ConvertItem* item )
                 //t_int -= t_int%plugin->enc.quality.step;
                 sQuality = QString::number( t_int );
             }
-            if( plugin->enc.lossy.quality.separator != '.' ) sQuality.replace(QChar('.'),plugin->enc.lossy.quality.separator);
+            if( plugin->enc.bin == "oggenc" ) sQuality.replace(QChar('.'),KGlobal::locale()->decimalSymbol()); // HACK make oggenc usable with all langauges
+            else if( plugin->enc.lossy.quality.separator != '.' ) sQuality.replace(QChar('.'),plugin->enc.lossy.quality.separator);
         }
         else {
             QStringList::Iterator it = plugin->enc.lossy.quality.profiles.at( rint(item->fileListItem->options.encodingOptions.iQuality*plugin->enc.lossy.quality.range_max/100) );
@@ -445,8 +471,9 @@ void Convert::encode( ConvertItem* item )
         param.append( " " + plugin->enc.replaygain.avoid );
     }
 
-    if( !tagEngine->canWrite(item->fileListItem->options.encodingOptions.sFormat) && item->fileListItem->tags && plugin->enc.tag.enabled ) {
-        if( plugin->enc.tag.param ) param.append( " " + plugin->enc.tag.param );
+//     if( !tagEngine->canWrite(item->fileListItem->options.encodingOptions.sFormat) && item->fileListItem->tags && plugin->enc.tag.enabled ) {
+    if( item->fileListItem->tags && plugin->enc.tag.enabled && item->fileListItem->options.encodingOptions.sFormat != "aac" ) { // HACK don't write metadata to aac
+        if( !plugin->enc.tag.param.isEmpty() ) param.append( " " + plugin->enc.tag.param );
         if( !plugin->enc.tag.artist.isEmpty() && !item->fileListItem->tags->artist.isEmpty() ) param.append( " " + plugin->enc.tag.artist );
         if( !plugin->enc.tag.album.isEmpty() && !item->fileListItem->tags->album.isEmpty() ) param.append( " " + plugin->enc.tag.album );
         if( !plugin->enc.tag.comment.isEmpty() && !item->fileListItem->tags->comment.isEmpty() ) param.append( " " + plugin->enc.tag.comment );
@@ -462,7 +489,7 @@ void Convert::encode( ConvertItem* item )
     param = sInOutFiles.replace( "%p", param );
 
     // cosmetic surgery
-    param.simplifyWhiteSpace();
+    param = param.simplifyWhiteSpace();
 
     params = QStringList::split( ' ', param );
 
@@ -483,18 +510,18 @@ void Convert::encode( ConvertItem* item )
         paramSplinter.replace( "%s", sSamplingRate );
 
         if( item->fileListItem->tags ) {
-            paramSplinter.replace( "%ta", item->fileListItem->tags->artist );
-            paramSplinter.replace( "%tb", item->fileListItem->tags->album );
-            paramSplinter.replace( "%tc", item->fileListItem->tags->comment );
-            paramSplinter.replace( "%td", QString::number(item->fileListItem->tags->disc) );
-            paramSplinter.replace( "%tg", item->fileListItem->tags->genre );
-            paramSplinter.replace( "%tn", QString::number(item->fileListItem->tags->track) );
-            paramSplinter.replace( "%tp", item->fileListItem->tags->composer );
-            paramSplinter.replace( "%tt", item->fileListItem->tags->title );
-            paramSplinter.replace( "%ty", QString::number(item->fileListItem->tags->year) );
+            paramSplinter.replace( "%ta", ( item->fileListItem->tags->artist != "" ) ? item->fileListItem->tags->artist : i18n("Unknown") );
+            paramSplinter.replace( "%tb", ( item->fileListItem->tags->album != "" ) ? item->fileListItem->tags->album : i18n("Unknown") );
+            paramSplinter.replace( "%tc", ( item->fileListItem->tags->comment != "" ) ? item->fileListItem->tags->comment : i18n("Unknown") );
+            paramSplinter.replace( "%td", ( QString::number(item->fileListItem->tags->disc) != "" ) ? QString::number(item->fileListItem->tags->disc) : "0" );
+            paramSplinter.replace( "%tg", ( item->fileListItem->tags->genre != "" ) ? item->fileListItem->tags->genre : i18n("Unknown") );
+            paramSplinter.replace( "%tn", ( QString::number(item->fileListItem->tags->track) != "" ) ? QString::number(item->fileListItem->tags->track) : "0" );
+            paramSplinter.replace( "%tp", ( item->fileListItem->tags->composer != "" ) ? item->fileListItem->tags->composer : i18n("Unknown") );
+            paramSplinter.replace( "%tt", ( item->fileListItem->tags->title != "" ) ? item->fileListItem->tags->title : i18n("Unknown") );
+            paramSplinter.replace( "%ty", ( QString::number(item->fileListItem->tags->year) != "" ) ? QString::number(item->fileListItem->tags->year) : "0" );
         }
 
-        *(item->convertProcess) << paramSplinter;
+        if( paramSplinter != "" && paramSplinter != " " ) *(item->convertProcess) << paramSplinter; // NOTE fixes wavpack encoding
     }
 
     param.replace( "%i", "\""+inputFile+"\"" );
@@ -507,14 +534,14 @@ void Convert::encode( ConvertItem* item )
     param.replace( "%s", sSamplingRate );
 
     if( item->fileListItem->tags ) {
-        param.replace( "%ta", item->fileListItem->tags->artist );
-        param.replace( "%tb", item->fileListItem->tags->album );
-        param.replace( "%tc", item->fileListItem->tags->comment );
+        param.replace( "%ta", "\""+item->fileListItem->tags->artist+"\"" );
+        param.replace( "%tb", "\""+item->fileListItem->tags->album+"\"" );
+        param.replace( "%tc", "\""+item->fileListItem->tags->comment+"\"" );
         param.replace( "%td", QString::number(item->fileListItem->tags->disc) );
-        param.replace( "%tg", item->fileListItem->tags->genre );
+        param.replace( "%tg", "\""+item->fileListItem->tags->genre+"\"" );
         param.replace( "%tn", QString::number(item->fileListItem->tags->track) );
-        param.replace( "%tp", item->fileListItem->tags->composer );
-        param.replace( "%tt", item->fileListItem->tags->title );
+        param.replace( "%tp", "\""+item->fileListItem->tags->composer+"\"" );
+        param.replace( "%tt", "\""+item->fileListItem->tags->title+"\"" );
         param.replace( "%ty", QString::number(item->fileListItem->tags->year) );
     }
 
@@ -589,20 +616,32 @@ void Convert::put( ConvertItem* item )
     else src = item->tempWavFile->name();
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Moving file")+"... 00 %" );
 
-    item->outputFilePathName = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config) );
+    item->outputFilePathName = OutputDirectory::makePath( OutputDirectory::uniqueFileName(OutputDirectory::calcPath(item->fileListItem,config)) ).replace("%2f","%252f");
 
     KURL source( src );
-//     KURL destination( item->outputFilePathName );
-    KURL destination;
-    destination.setPath( item->outputFilePathName );
+    KURL destination( item->outputFilePathName );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::putCorrection( ConvertItem* item )
@@ -612,7 +651,7 @@ void Convert::putCorrection( ConvertItem* item )
 
     QString src = item->correctionOutFile;
 
-    QString dest = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config,item->correctionOutputExtension) );
+    QString dest = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config,item->correctionOutputExtension) ).replace("%2f","%252f");
 
     KURL source( src );
 //     KURL destination( dest );
@@ -621,13 +660,52 @@ void Convert::putCorrection( ConvertItem* item )
 
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Moving correction file")+"... 00 %" );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
+}
+
+void Convert::executeUserScript( ConvertItem* item )
+{
+    logger->log( item->logID, i18n("Running user script") );
+    item->state = ConvertItem::execute_userscript;
+
+    KURL source( item->fileListItem->options.filePathName );
+    KURL destination( item->outputFilePathName );
+
+    item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Running user script")+"... 00 %" );
+
+    item->convertProcess->clearArguments();
+
+    QString userscript = locate( "data", "soundkonverter/userscript.sh" );
+    if( userscript == "" ) executeNextStep( item );
+
+    *(item->convertProcess) << userscript;
+    *(item->convertProcess) << source.path();
+    *(item->convertProcess) << destination.path();
+
+    logger->log( item->logID, userscript + " \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+    item->convertProcess->setPriority( config->data.general.priority );
+    item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
 }
 
 void Convert::executeNextStep( ConvertItem* item )
@@ -649,6 +727,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -661,6 +740,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -672,6 +752,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -682,6 +763,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -691,6 +773,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -699,6 +782,7 @@ void Convert::executeNextStep( ConvertItem* item )
             if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -706,16 +790,24 @@ void Convert::executeNextStep( ConvertItem* item )
         {
             if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
         case ConvertItem::put:
         {
             if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
         case ConvertItem::put_correction:
+        {
+            if( config->data.general.executeUserScript ) executeUserScript( item );
+            else remove( item );
+            break;
+        }
+        case ConvertItem::execute_userscript:
         {
             remove( item );
             break;
@@ -731,6 +823,7 @@ void Convert::executeNextStep( ConvertItem* item )
             else if( item->mode & ConvertItem::write_tags ) writeTags( item );
             else if( item->mode & ConvertItem::put ) put( item );
             else if( item->mode & ConvertItem::put_correction ) putCorrection( item );
+            else if( config->data.general.executeUserScript ) executeUserScript( item );
             else remove( item );
             break;
         }
@@ -1015,6 +1108,46 @@ void Convert::processExit( KProcess* proc )
                     emit rippingFinished( (*item)->fileListItem->device );
                 }
             }
+            if( (*item)->state == ConvertItem::get ) {
+                if( proc->signalled() ) {
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else if( !proc->normalExit() ) {
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("Got file") );
+
+                    // if file is remote or the tag reding failed previously, read the tags now
+                    if( (*item)->fileListItem->tags == 0 ) {
+                        (*item)->fileListItem->tags = tagEngine->readTags( (*item)->tempInFile->name() );
+                    }
+
+                    emit countTime( (*item)->getTime );
+                }
+            }
+            if( (*item)->state == ConvertItem::get_correction ) {
+                if( proc->signalled() ) {
+                    emit uncountTime( (*item)->getTime );
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else if( !proc->normalExit() ) {
+                    emit uncountTime( (*item)->getTime );
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("Got file") );
+                    emit countTime( (*item)->getCorrectionTime );
+                }
+            }
             if( (*item)->state == ConvertItem::decode ) {
                 if( proc->signalled() ) {
                     emit uncountTime( (*item)->getTime );
@@ -1066,6 +1199,62 @@ void Convert::processExit( KProcess* proc )
                     emit countTime( (*item)->encodeTime );
                 }
             }
+            if( (*item)->state == ConvertItem::put ) {
+                if( proc->signalled() ) {
+                    logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                if( !proc->normalExit() ) {
+                    logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("File moved") );
+                }
+            }
+            if( (*item)->state == ConvertItem::put_correction ) {
+                if( proc->signalled() ) {
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                if( !proc->normalExit() ) {
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("File moved") );
+                }
+            }
             if( (*item)->state == ConvertItem::replaygain ) {
                 if( proc->signalled() ) {
                     emit uncountTime( (*item)->getTime );
@@ -1100,7 +1289,7 @@ void Convert::processExit( KProcess* proc )
 
 void Convert::add( FileListItem* item )
 {
-    logger->log( 1000, i18n("Adding new item to conversion list: `%1')").arg(item->options.filePathName) );
+    logger->log( 1000, i18n("Adding new item to conversion list: `%1'").arg(item->options.filePathName) );
 
     // append the item to the item list and store the iterator
     QValueList<ConvertItem*>::Iterator newItem = items.append( new ConvertItem( item ) );
@@ -1260,6 +1449,7 @@ void Convert::stop( FileListItem* item )
             else if( (*stopItem)->moveJob != 0 ) {
                 //kdDebug() << "Killing file copy..." << endl;
                 // FIXME crashes sometimes - should be fixed by SIGKILL
+                // FIXME crash if file_copy was stealthed
                 logger->log( (*stopItem)->logID, i18n("Killing process ...") );
                 (*stopItem)->moveJob->kill( false );
             }
@@ -1353,7 +1543,7 @@ void Convert::updateProgressIndicator()
         }
         else if( (*it)->state == ConvertItem::rip ) {
             RipperPlugin* plugin = config->getCurrentRipper();
-            if( plugin->rip.output.isEmpty() ) {
+            if( plugin != 0 && plugin->rip.output.isEmpty() ) {
                 (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Ripping")+"... "+i18n("State")+": "+i18n("Unknown") );
             }
             else {
